@@ -24,9 +24,6 @@ mod haxports {
 #[cfg(feature = "hax")]
 pub use haxports::*;
 
-#[cfg(feature = "server-plugin")]
-pub use gmserverplugin as serverplugin;
-
 /// Lua interface
 pub mod lua;
 
@@ -152,7 +149,7 @@ macro_rules! open_library_srv {
 				$crate::open_library_raw!("bin/", $name, ".so"),
 				$crate::open_library_raw!("bin/lib", $name, ".so"),
 				$crate::open_library_raw!("garrysmod/bin/", $name, ".so"),
-				$crate::open_library_raw!("garrysmod/bin/lib", $name, ".so"),
+				$crate::open_library_raw!("garrysmod/bin/lib", $name, ".so")
 			}
 		}
 	}};
@@ -182,14 +179,14 @@ macro_rules! open_library {
 		#[cfg(all(target_os = "windows", target_pointer_width = "32"))] {
 			$crate::__private__gmod_rs__try_chained_open! {
 				$crate::open_library_raw!("bin/", $name, ".dll"),
-				$crate::open_library_raw!("garrysmod/bin/", $name, ".dll"),
+				$crate::open_library_raw!("garrysmod/bin/", $name, ".dll")
 			}
 		}
 
 		#[cfg(all(target_os = "linux", target_pointer_width = "64"))] {
 			$crate::__private__gmod_rs__try_chained_open! {
 				$crate::open_library_raw!("bin/linux64/", $name, ".so"),
-				$crate::open_library_raw!("bin/linux64/lib", $name, ".so"),
+				$crate::open_library_raw!("bin/linux64/lib", $name, ".so")
 			}
 		}
 		#[cfg(all(target_os = "linux", target_pointer_width = "32"))] {
@@ -203,7 +200,7 @@ macro_rules! open_library {
 				$crate::open_library_raw!("bin/", $name, "_srv.so"),
 				$crate::open_library_raw!("bin/lib", $name, "_srv.so"),
 				$crate::open_library_raw!("garrysmod/bin/", $name, "_srv.so"),
-				$crate::open_library_raw!("garrysmod/bin/lib", $name, "_srv.so"),
+				$crate::open_library_raw!("garrysmod/bin/lib", $name, "_srv.so")
 			}
 		}
 	}};
