@@ -511,6 +511,11 @@ impl LuaState {
 		(LUA_SHARED.lua_xmove)(*self, target_thread, n)
 	}
 
+	#[inline(always)]
+	pub unsafe fn equal(&self, index1: i32, index2: i32) -> bool {
+		(LUA_SHARED.lua_equal)(*self, index1, index2) == 1
+	}
+
 	#[inline(always)]
 	/// See `call`
 	pub unsafe fn coroutine_resume_call(&self, narg: i32) {
